diff --git a/dashboard/oidc_auth.py b/dashboard/oidc_auth.py
index f68ae80c..e8abf4bd 100644
--- a/dashboard/oidc_auth.py
+++ b/dashboard/oidc_auth.py
@@ -67,7 +67,7 @@ def _get_connection_name(self, connection):
CONNECTION_NAMES = {
"google-oauth2": "Google",
"github": "GitHub",
- "firefoxaccounts": "Firefox Accounts",
+ "firefoxaccounts": "Mozilla Accounts",
"Mozilla-LDAP-Dev": "LDAP",
"Mozilla-LDAP": "LDAP",
"email": "passwordless email",
@@ -107,10 +107,10 @@ def error_message(self):
to setup your device, then try logging in again.'
elif error_code == "fxarequiremfa":
error_text = 'Please \
secure your Firefox Account with two-step authentication, \
then try logging in again.\n
\n\
If you have just setup your security device and you see this message, please log out of \
- Firefox Accounts (click the "Sign out" button), then \
+ Mozilla Accounts (click the "Sign out" button), then \
log back in.'
elif error_code == "notingroup":
error_text = "Sorry, you do not have permission to access {client}. \
@@ -138,7 +138,7 @@ def error_message(self):
elif error_code == "aai_failed":
error_text = "{client} requires you to setup additional security measures for your account, \
such as enabling multi-factor authentication (MFA) or using a safer authentication method (such as a \
Firefox Account login). You will not be able to login until this is \
done.".format(
client=self.data.get("client")
)
@@ -107,10 +107,10 @@ def error_message(self):
elif error_code == "fxarequiremfa":
error_text = 'Please \
- secure your Firefox Account with two-step authentication, \
+ secure your Mozilla Account with two-step authentication, \
then try logging in again.\n
\n\
@@ -138,7 +138,7 @@ def error_message(self):
error_text = "{client} requires you to setup additional security measures for your account, \
such as enabling multi-factor authentication (MFA) or using a safer authentication method (such as a \
- Firefox Account login). You will not be able to login until this is \
+ Mozilla Account login). You will not be able to login until this is \
done.".format(
client=self.data.get("client")